@@ -33,9 +33,10 @@
 #  define KWINDOWSYSTEM_DEPRECATED_NO_EXPORT KWINDOWSYSTEM_NO_EXPORT KWINDOWSYSTEM_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KWINDOWSYSTEM_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#    define KWINDOWSYSTEM_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
